@@ -256,11 +256,6 @@ public class LdapGlobalFolderCreator {
                 return null;
             }
 
-            @Override
-            public void removeRandomToken() {
-                // Nothing to do
-            }
-
             @Override
             public void setParameter(final String name, final Object value) {
                 // Nothing to do
@@ -297,6 +292,11 @@ public class LdapGlobalFolderCreator {
 
             }
 
+            @Override
+            public boolean isTransient() {
+                return false;
+            }
+
         };
     }
 
